@@ -15,7 +15,7 @@
 
 There should be a file 'ftesting.zcml' in the current directory.
 
-$Id: functional.py 97753 2009-03-10 01:19:59Z rogerineichen $
+$Id: functional.py 105881 2009-11-19 16:31:33Z tlotze $
 """
 import copy
 import logging
@@ -49,7 +49,8 @@ from zope.app.publication.http import HTTPPublication
 from zope.app.publication.zopepublication import ZopePublication
 from zope.app.publication.http import HTTPPublication
 from zope.app.publication.httpfactory import chooseClasses
-from zope.site.hooks import setSite, getSite
+from zope.component.hooks import setSite, getSite
+
 
 class ResponseWrapper(object):
     """A wrapper that adds several introspective methods to a response."""
@@ -785,7 +786,7 @@ def _prepare_doctest_keywords(kw):
 
     kwsetUp = kw.get('setUp')
     def setUp(test):
-	test.globs['http'] = HTTPCaller()
+        test.globs['http'] = HTTPCaller()
         FunctionalTestSetup().setUp()
         if kwsetUp is not None:
             kwsetUp(test)
