@@ -13,18 +13,11 @@
 ##############################################################################
 """Setting up an environment for testing context-dependent objects
 
-$Id: setup.py 95595 2009-01-30 17:26:51Z thefunny42 $
+$Id: setup.py 105881 2009-11-19 16:31:33Z tlotze $
 """
 import zope.component
 import zope.traversing.api
 
-import zope.deferredimport
-zope.deferredimport.deprecatedFrom(
-    "Goes away in Zope 3.5",
-    "zope.app.testing.back35",
-    "addService",
-    )
-
 #------------------------------------------------------------------------
 # Annotations
 from zope.annotation.attribute import AttributeAnnotations
@@ -62,12 +55,12 @@ def setUpSiteManagerLookup():
 
 #------------------------------------------------------------------------
 # Placeful setup
-import zope.site.hooks
+import zope.component.hooks
 from zope.app.testing.placelesssetup import setUp as placelessSetUp
 from zope.app.testing.placelesssetup import tearDown as placelessTearDown
 def placefulSetUp(site=False):
     placelessSetUp()
-    zope.site.hooks.setHooks()
+    zope.component.hooks.setHooks()
     setUpAnnotations()
     setUpDependable()
     setUpTraversal()
@@ -78,11 +71,10 @@ def placefulSetUp(site=False):
         createSiteManager(site, setsite=True)
         return site
 
-from zope.site.hooks import setSite
 def placefulTearDown():
     placelessTearDown()
-    zope.site.hooks.resetHooks()
-    setSite()
+    zope.component.hooks.resetHooks()
+    zope.component.hooks.setSite()
 
 #------------------------------------------------------------------------
 # Sample Folder Creation
@@ -130,12 +122,13 @@ def buildSampleFolderTree():
 #------------------------------------------------------------------------
 # Sample Folder Creation
 from zope.site.site import LocalSiteManager
-from zope.location.interfaces import ISite
+import zope.component.interfaces
+
 def createSiteManager(folder, setsite=False):
-    if not ISite.providedBy(folder):
+    if not zope.component.interfaces.ISite.providedBy(folder):
         folder.setSiteManager(LocalSiteManager(folder))
     if setsite:
-        setSite(folder)
+        zope.component.hooks.setSite(folder)
     return zope.traversing.api.traverse(folder, "++etc++site")
 
 
